==> nextcloud-11.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/ca.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "No es pot escriure a la carpeta \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Això normalment es pot solucionar donant al servidor web permís d'escriptura a la carpeta de configuració",
    "See %s" : "Comproveu %s",
    "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta de configuració %s",
    "Sample configuration detected" : "Configuració d'exemple detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S'ha detectat que la configuració d'exemple ha estat copiada. Això no està suportat, i podria corrompre la vostra instalació. Siusplau, llegiu la documentació abans de realitzar canvis a config.php",
    "%1$s and %2$s" : "%1$s i %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
    "PHP %s or higher is required." : "Es requereix PHP %s o superior.",
    "Server version %s or higher is required." : "Es requereix una versió de servidor %s o superior",
    "Server version %s or lower is required." : "Es requereix una versió de servidor %s o inferior",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "Invalid image" : "Imatge no vàlida",
    "Avatar image is not square" : "La imatge de perfil no és quadrada",
    "today" : "avui",
    "yesterday" : "ahir",
    "_%n day ago_::_%n days ago_" : ["fa %n dia","fa %n dies"],
    "last month" : "el mes passat",
    "_%n month ago_::_%n months ago_" : ["fa %n mes","fa %n mesos"],
    "last year" : "l'any passat",
    "_%n year ago_::_%n years ago_" : ["fa %n any","fa %n anys"],
    "_%n hour ago_::_%n hours ago_" : ["fa %n hora","fa %n hores"],
    "_%n minute ago_::_%n minutes ago_" : ["fa %n minut","fa %n minuts"],
    "seconds ago" : "segons enrere",
    "File name contains at least one invalid character" : "El nom del fitxer conté al menys un caràcter invàlid",
    "File name is too long" : "el nom del fitxer es massa gran",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Server settings" : "Configuració del Servidor",
    "Sharing" : "Compartir",
    "Encryption" : "Xifrat",
    "Additional settings" : "Configuració adicional",
    "Tips & tricks" : "Consells i trucs",
    "%s enter the database username and name." : "%s escriviu el nom d'usuari i el nom de la base de dades.",
    "%s enter the database username." : "%s escriviu el nom d'usuari de la base de dades.",
    "%s enter the database name." : "%s escriviu el nom de la base de dades.",
    "%s you may not use dots in the database name" : "%s no podeu usar punts en el nom de la base de dades",
    "Oracle connection could not be established" : "No s'ha pogut establir la connexió Oracle",
    "Oracle username and/or password not valid" : "Nom d'usuari i/o contrasenya Oracle no vàlids",
    "DB Error: \"%s\"" : "Error DB: \"%s\"",
    "Offending command was: \"%s\"" : "L'ordre en conflicte és: \"%s\"",
    "You need to enter either an existing account or the administrator." : "Heu d'escriure un compte existent o el d'administrador.",
    "Offending command was: \"%s\", name: %s, password: %s" : "L'ordre en conflicte és: \"%s\", nom: %s, contrasenya: %s",
    "PostgreSQL username and/or password not valid" : "Nom d'usuari i/o contrasenya PostgreSQL no vàlids",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no té suport i %s no funcionarà correctament en aquesta plataforma. Useu-ho al vostre risc!",
    "For the best results, please consider using a GNU/Linux server instead." : "Per millors resultats, millor considereu utilitzar un servidor GNU/Linux.",
    "Set an admin username." : "Establiu un nom d'usuari per l'administrador.",
    "Set an admin password." : "Establiu una contrasenya per l'administrador.",
    "Invalid Federated Cloud ID" : "ID de núvol federat invàlid",
    "%s shared »%s« with you" : "%s ha compartit »%s« amb tu",
    "%s via %s" : "%s via %s",
    "Sharing %s failed, because the file does not exist" : "Ha fallat en compartir %s, perquè el fitxer no existeix",
    "You are not allowed to share %s" : "No se us permet compartir %s",
    "Sharing %s failed, because the user %s does not exist" : "Ha fallat en compartir %s, perquè l'usuari %s no existeix",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Ha fallat en compartir %s, perquè l'usuari %s no és membre de cap grup dels que %s és membre",
    "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
    "Sharing %s failed, because the group %s does not exist" : "Ha fallat en compartir %s, perquè el grup %s no existeix",
    "Sharing %s failed, because %s is not a member of the group %s" : "Ha fallat en compartir %s, perquè %s no és membre del grup %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Heu de proporcionar una contrasenya per crear un enllaç públic. Només es permeten enllaços segurs.",
    "Sharing %s failed, because sharing with links is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir amb enllaços",
    "Not allowed to create a federated share with the same user" : "No està permés crear una compartició federada amb el mateix usuari",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "La compartició de %s ha fallat, no es pot trobar %s, potser el servidor està actualment innacessible.",
    "Share type %s is not valid for %s" : "La compartició tipus %s no és vàlida per %s",
    "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Ha fallat en establir els permisos per %s perquè aquests excedeixen els permesos per a %s",
    "Setting permissions for %s failed, because the item was not found" : "Ha fallat en establir els permisos per %s, perquè no s'ha trobat l'element",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No es pot guardar la data d'expiració. Els fitxers o carpetes compartits no poden expirar més tard de %s després d'haver-se compratit.",
    "Cannot set expiration date. Expiration date is in the past" : "No es pot guardar la data d'expiració. La data d'expiració ja ha passat.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El rerefons de compartició %s ha d'implementar la interfície OCP\\Share_Backend",
    "Sharing backend %s not found" : "El rerefons de compartició %s no s'ha trobat",
    "Sharing backend for %s not found" : "El rerefons de compartició per a %s no s'ha trobat",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Ha fallat en compartir %s perquè els permisos excedeixen els permesos per a %s",
    "Sharing %s failed, because resharing is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir de nou",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ha fallat en compartir %s, perquè el rerefons de compartir per %s no pot trobar la seva font",
    "Sharing %s failed, because the file could not be found in the file cache" : "Ha fallat en compartir %s, perquè el fitxer no s'ha trobat en el fitxer cau",
    "Could not find category \"%s\"" : "No s'ha trobat la categoria \"%s\"",
    "Sunday" : "Diumenge",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sun." : "Dg.",
    "Mon." : "Mon.",
    "Tue." : "Dm.",
    "Wed." : "Dc.",
    "Thu." : "Dj.",
    "Fri." : "Dv.",
    "Sat." : "Ds.",
    "Su" : "Dg",
    "Mo" : "Dl",
    "Tu" : "Dm",
    "We" : "Dc",
    "Th" : "Dj",
    "Fr" : "Dv",
    "Sa" : "Ds",
    "January" : "Gener",
    "February" : "Febrer",
    "March" : "Març",
    "April" : "Abril",
    "May" : "Maig",
    "June" : "Juny",
    "July" : "Juliol",
    "August" : "Agost",
    "September" : "Setembre",
    "October" : "Octubre",
    "November" : "Novembre",
    "December" : "Desembre",
    "Jan." : "Gen.",
    "Feb." : "Febr.",
    "Mar." : "Març",
    "Apr." : "Abr",
    "May." : "Maig",
    "Jun." : "Juny",
    "Jul." : "Jul.",
    "Aug." : "Ag.",
    "Sep." : "Set",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "Apps" : "Aplicacions",
    "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
    "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
    "The username is already being used" : "El nom d'usuari ja està en ús",
    "Login canceled by app" : "Accés cancel·lat per l'App",
    "User disabled" : "Usuari desactivat",
    "Help" : "Ajuda",
    "Personal" : "Personal",
    "Users" : "Usuaris",
    "Admin" : "Administració",
    "No app name specified" : "No heu especificat cap nom d'aplicació",
    "Can't read file" : "No es pot llegir el fitxer",
    "Application is not enabled" : "L'aplicació no està habilitada",
    "Authentication error" : "Error d'autenticació",
    "Token expired. Please reload page." : "El testimoni ha expirat. Torneu a carregar la pàgina.",
    "Unknown user" : "Usuari desconegut",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No hi ha instal·lats controladors de bases de dades (sqlite, mysql o postgresql).",
    "Cannot write into \"config\" directory" : "No es pot escriure a la carpeta \"config\"",
    "Cannot write into \"apps\" directory" : "No es pot escriure a la carpeta \"apps\"",
    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta d'aplicacions %s o inhabilitant la botiga d'aplicacions en el fitxer de configuració.",
    "Cannot create \"data\" directory (%s)" : "No es pot crear la carpeta \"data\" (%s)",
    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Això normalment es pot solucionar donant a %s permís d'escriptura a la carpeta de configuració %s",
    "Setting locale to %s failed" : "Ha fallat en establir la llengua a %s",
    "Please install one of these locales on your system and restart your webserver." : "Siusplau, instal·li un d'aquests arxius de localització en el seu sistema, i reinicii el seu servidor web.",
    "Please ask your server administrator to install the module." : "Demaneu a l'administrador del sistema que instal·li el mòdul.",
    "PHP module %s not installed." : "El mòdul PHP %s no està instal·lat.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement està provocat per una cau/accelerador com Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "S'han instal·lat mòduls PHP, però encara es llisten com una mancança?",
    "Please ask your server administrator to restart the web server." : "Demaneu a l'administrador que reinici el servidor web.",
    "PostgreSQL >= 9 required" : "Es requereix PostgreSQL >= 9",
    "Please upgrade your database version" : "Actualitzeu la versió de la base de dades",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Canvieu els permisos a 0770 per tal que la carpeta no es pugui llistar per altres usuaris.",
    "Data directory (%s) is readable by other users" : "La carpeta de dades (%s) és llegible per altres usuaris",
    "Data directory (%s) is invalid" : "La carpeta de dades (%s) no és vàlida",
    "Please check that the data directory contains a file \".ocdata\" in its root." : "Comproveu que la carpeta de dades contingui un fitxer \".ocdata\" a la seva arrel.",
    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir un bloqueig tipus %d a \"%s\".",
    "App directory already exists" : "La carpeta de l'aplicació ja existeix",
    "Can't create app folder. Please fix permissions. %s" : "No es pot crear la carpeta de l'aplicació. Arregleu els permisos. %s",
    "No source specified when installing app" : "No heu especificat la font en instal·lar l'aplicació",
    "No href specified when installing app from http" : "No heu especificat href en instal·lar l'aplicació des de http",
    "No path specified when installing app from local file" : "No heu seleccionat el camí en instal·lar una aplicació des d'un fitxer local",
    "Archives of type %s are not supported" : "Els fitxers del tipus %s no són compatibles",
    "Failed to open archive when installing app" : "Ha fallat l'obertura del fitxer en instal·lar l'aplicació",
    "App does not provide an info.xml file" : "L'aplicació no proporciona un fitxer info.xml",
    "App can't be installed because of not allowed code in the App" : "L'aplicació no es pot instal·lar perquè hi ha codi no autoritzat en l'aplicació",
    "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "L'aplicació no es pot instal·lar perquè conté l'etiqueta <shipped>vertader</shipped> que no es permet per aplicacions no enviades",
    "Logging" : "Iniciant",
    "Recommended" : "Recomanat",
    "Microsoft Windows Platform is not supported" : "La plataforma de Microsoft Windows no està soportat!",
    "Storage not available" : "Emmagatzemament no disponible"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/ca.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "No es pot escriure a la carpeta \"config\"!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "Això normalment es pot solucionar donant al servidor web permís d'escriptura a la carpeta de configuració",
    "See %s" : "Comproveu %s",
    "Sample configuration detected" : "Configuració d'exemple detectada",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "S'ha detectat que la configuració d'exemple ha estat copiada. Això no està suportat, i podria corrompre la vostra instalació. Siusplau, llegiu la documentació abans de realitzar canvis a config.php",
    "%1$s and %2$s" : "%1$s i %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s i %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s i %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s i %5$s",
    "Education Edition" : "Edició educativa",
    "Enterprise bundle" : "Paquet empresarial",
    "Groupware bundle" : "Paquet de treball en grup",
    "Social sharing bundle" : "Paquet social",
    "PHP %s or higher is required." : "Es requereix PHP %s o superior.",
    "PHP with a version lower than %s is required." : "Es requereix php amb versió menor a %s.",
    "%sbit or higher PHP required." : "Es requereix PHP %s o superior.",
    "Following databases are supported: %s" : "Es suporten les següents bases de dades: %s",
    "The command line tool %s could not be found" : "No s'ha pogut trobar l'eina per intèrpret de comandes %s",
    "Server version %s or higher is required." : "Es requereix una versió de servidor %s o superior",
    "Server version %s or lower is required." : "Es requereix una versió de servidor %s o inferior",
    "Unknown filetype" : "Tipus de fitxer desconegut",
    "Invalid image" : "Imatge no vàlida",
    "Avatar image is not square" : "La imatge de perfil no és quadrada",
    "today" : "avui",
    "tomorrow" : "demà",
    "yesterday" : "ahir",
    "_in %n day_::_in %n days_" : ["d'aquí %n dia","d'aquí %n dies"],
    "_%n day ago_::_%n days ago_" : ["fa %n dia","fa %n dies"],
    "next month" : "mes següent",
    "last month" : "el mes passat",
    "_in %n month_::_in %n months_" : ["d'aquí %n mesos","d'aquí %n mesos"],
    "_%n month ago_::_%n months ago_" : ["fa %n mes","fa %n mesos"],
    "next year" : "any següent",
    "last year" : "l'any passat",
    "_in %n year_::_in %n years_" : ["d'aquí %n any","d'aquí %n anys"],
    "_%n year ago_::_%n years ago_" : ["fa %n any","fa %n anys"],
    "_in %n hour_::_in %n hours_" : ["d'aquí %n hora","d'aquí %n hores"],
    "_%n hour ago_::_%n hours ago_" : ["fa %n hora","fa %n hores"],
    "_in %n minute_::_in %n minutes_" : ["d'aquí %n minut","d'aquí %n minuts"],
    "_%n minute ago_::_%n minutes ago_" : ["fa %n minut","fa %n minuts"],
    "in a few seconds" : "en uns segons",
    "seconds ago" : "segons enrere",
    "File name is a reserved word" : "El nom de fitxer és una paraula reservada",
    "File name contains at least one invalid character" : "El nom del fitxer conté al menys un caràcter invàlid",
    "File name is too long" : "el nom del fitxer es massa gran",
    "Dot files are not allowed" : "No estan permesos fitxers amb punt",
    "Empty filename is not allowed" : "Mo estan permesos noms buits",
    "Help" : "Ajuda",
    "Apps" : "Aplicacions",
    "Settings" : "Preferències",
    "Log out" : "Surt",
    "Users" : "Usuaris",
    "Unknown user" : "Usuari desconegut",
    "APCu" : "APCu",
    "Redis" : "Redis",
    "Create" : "Crea",
    "Change" : "Modifica",
    "Delete" : "Esborra",
    "Share" : "Comparteix",
    "Basic settings" : "Configuració bàsica",
    "Sharing" : "Compartir",
    "Security" : "Seguretat",
    "Encryption" : "Xifrat",
    "Additional settings" : "Configuració adicional",
    "Tips & tricks" : "Consells i trucs",
    "Personal info" : "Informació personal",
    "Unlimited" : "Il·limitat",
    "__language_name__" : "Català",
    "Verifying" : "Verificant",
    "Verifying …" : "Verificant ...",
    "Verify" : "Verifica",
    "%s enter the database username and name." : "%s escriviu el nom d'usuari i el nom de la base de dades.",
    "%s enter the database username." : "%s escriviu el nom d'usuari de la base de dades.",
    "%s enter the database name." : "%s escriviu el nom de la base de dades.",
    "%s you may not use dots in the database name" : "%s no podeu usar punts en el nom de la base de dades",
    "Oracle connection could not be established" : "No s'ha pogut establir la connexió Oracle",
    "Oracle username and/or password not valid" : "Nom d'usuari i/o contrasenya Oracle no vàlids",
    "PostgreSQL username and/or password not valid" : "Nom d'usuari i/o contrasenya PostgreSQL no vàlids",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X no té suport i %s no funcionarà correctament en aquesta plataforma. Useu-ho al vostre risc!",
    "For the best results, please consider using a GNU/Linux server instead." : "Per millors resultats, millor considereu utilitzar un servidor GNU/Linux.",
    "Set an admin username." : "Establiu un nom d'usuari per l'administrador.",
    "Set an admin password." : "Establiu una contrasenya per l'administrador.",
    "Invalid Federated Cloud ID" : "ID de núvol federat invàlid",
    "Sharing %s failed, because the file does not exist" : "Ha fallat en compartir %s, perquè el fitxer no existeix",
    "You are not allowed to share %s" : "No se us permet compartir %s",
    "Sharing %s failed, because the user %s does not exist" : "Ha fallat en compartir %s, perquè l'usuari %s no existeix",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Ha fallat en compartir %s, perquè l'usuari %s no és membre de cap grup dels que %s és membre",
    "Sharing %s failed, because this item is already shared with %s" : "Ha fallat en compartir %s, perquè l'element ja està compartit amb %s",
    "Sharing %s failed, because the group %s does not exist" : "Ha fallat en compartir %s, perquè el grup %s no existeix",
    "Sharing %s failed, because %s is not a member of the group %s" : "Ha fallat en compartir %s, perquè %s no és membre del grup %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "Heu de proporcionar una contrasenya per crear un enllaç públic. Només es permeten enllaços segurs.",
    "Sharing %s failed, because sharing with links is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir amb enllaços",
    "Not allowed to create a federated share with the same user" : "No està permés crear una compartició federada amb el mateix usuari",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "La compartició de %s ha fallat, no es pot trobar %s, potser el servidor està actualment innacessible.",
    "Share type %s is not valid for %s" : "La compartició tipus %s no és vàlida per %s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "No es pot guardar la data d'expiració. Els fitxers o carpetes compartits no poden expirar més tard de %s després d'haver-se compratit.",
    "Cannot set expiration date. Expiration date is in the past" : "No es pot guardar la data d'expiració. La data d'expiració ja ha passat.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "El rerefons de compartició %s ha d'implementar la interfície OCP\\Share_Backend",
    "Sharing backend %s not found" : "El rerefons de compartició %s no s'ha trobat",
    "Sharing backend for %s not found" : "El rerefons de compartició per a %s no s'ha trobat",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Ha fallat en compartir %s perquè els permisos excedeixen els permesos per a %s",
    "Sharing %s failed, because resharing is not allowed" : "Ha fallat en compartir %s, perquè no es permet compartir de nou",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Ha fallat en compartir %s, perquè el rerefons de compartir per %s no pot trobar la seva font",
    "Sharing %s failed, because the file could not be found in the file cache" : "Ha fallat en compartir %s, perquè el fitxer no s'ha trobat en el fitxer cau",
    "%s shared »%s« with you" : "%s ha compartit »%s« amb tu",
    "%s via %s" : "%s via %s",
    "Could not find category \"%s\"" : "No s'ha trobat la categoria \"%s\"",
    "Sunday" : "Diumenge",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Sun." : "Dg.",
    "Mon." : "Mon.",
    "Tue." : "Dm.",
    "Wed." : "Dc.",
    "Thu." : "Dj.",
    "Fri." : "Dv.",
    "Sat." : "Ds.",
    "Su" : "Dg",
    "Mo" : "Dl",
    "Tu" : "Dm",
    "We" : "Dc",
    "Th" : "Dj",
    "Fr" : "Dv",
    "Sa" : "Ds",
    "January" : "Gener",
    "February" : "Febrer",
    "March" : "Març",
    "April" : "Abril",
    "May" : "Maig",
    "June" : "Juny",
    "July" : "Juliol",
    "August" : "Agost",
    "September" : "Setembre",
    "October" : "Octubre",
    "November" : "Novembre",
    "December" : "Desembre",
    "Jan." : "Gen.",
    "Feb." : "Febr.",
    "Mar." : "Març",
    "Apr." : "Abr",
    "May." : "Maig",
    "Jun." : "Juny",
    "Jul." : "Jul.",
    "Aug." : "Ag.",
    "Sep." : "Set",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Des.",
    "A valid username must be provided" : "Heu de facilitar un nom d'usuari vàlid",
    "A valid password must be provided" : "Heu de facilitar una contrasenya vàlida",
    "The username is already being used" : "El nom d'usuari ja està en ús",
    "Could not create user" : "No s'ha pogut crear l'usuari",
    "User disabled" : "Usuari desactivat",
    "Login canceled by app" : "Accés cancel·lat per l'App",
    "a safe home for all your data" : "un lloc segur per a les teves dades",
    "Can't read file" : "No es pot llegir el fitxer",
    "Application is not enabled" : "L'aplicació no està habilitada",
    "Authentication error" : "Error d'autenticació",
    "Token expired. Please reload page." : "El testimoni ha expirat. Torneu a carregar la pàgina.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No hi ha instal·lats controladors de bases de dades (sqlite, mysql o postgresql).",
    "Cannot write into \"config\" directory" : "No es pot escriure a la carpeta \"config\"",
    "Cannot write into \"apps\" directory" : "No es pot escriure a la carpeta \"apps\"",
    "Setting locale to %s failed" : "Ha fallat en establir la llengua a %s",
    "Please install one of these locales on your system and restart your webserver." : "Siusplau, instal·li un d'aquests arxius de localització en el seu sistema, i reinicii el seu servidor web.",
    "Please ask your server administrator to install the module." : "Demaneu a l'administrador del sistema que instal·li el mòdul.",
    "PHP module %s not installed." : "El mòdul PHP %s no està instal·lat.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Això probablement està provocat per una cau/accelerador com Zend OPcache o eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "S'han instal·lat mòduls PHP, però encara es llisten com una mancança?",
    "Please ask your server administrator to restart the web server." : "Demaneu a l'administrador que reinici el servidor web.",
    "PostgreSQL >= 9 required" : "Es requereix PostgreSQL >= 9",
    "Please upgrade your database version" : "Actualitzeu la versió de la base de dades",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Canvieu els permisos a 0770 per tal que la carpeta no es pugui llistar per altres usuaris.",
    "Could not obtain lock type %d on \"%s\"." : "No s'ha pogut obtenir un bloqueig tipus %d a \"%s\".",
    "Personal" : "Personal"
},
"nplurals=2; plural=(n != 1);");
